bayespy.inference.vmp.nodes.wishart.WishartDistribution
=======================================================

.. currentmodule:: bayespy.inference.vmp.nodes.wishart

.. autoclass:: WishartDistribution

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~WishartDistribution.compute_cgf_from_parents
      ~WishartDistribution.compute_fixed_moments_and_f
      ~WishartDistribution.compute_gradient
      ~WishartDistribution.compute_logpdf
      ~WishartDistribution.compute_mask_to_parent
      ~WishartDistribution.compute_message_to_parent
      ~WishartDistribution.compute_moments_and_cgf
      ~WishartDistribution.compute_phi_from_parents
      ~WishartDistribution.plates_from_parent
      ~WishartDistribution.plates_to_parent
      ~WishartDistribution.random
   
   

   
   
   